@@ -123,20 +123,25 @@ DLReal GetBLFFTRMSLevel(const DLComplex * FFTArray,const int FFTSize,const int S
 
 /* Effettua la normalizzazione del segnale al valore indicato e
 secondo il metodo indicato */
-void SigNormalize(DLReal * Sig,const int SigLen,const DLReal NormFactor,
+Boolean SigNormalize(DLReal * Sig,const int SigLen,const DLReal NormFactor,
 	const NormType TNorm)
 	{
 		DLReal NormBase;
 		int I;
+		DLComplex * PFA;
+		DLReal CAV;
 
 		switch (TNorm)
 			{
 				case NormEuclidean:
 					{
 						NormBase = GetRMSLevel(Sig,SigLen);
-						if (NormBase > (DLReal) 0.0)
-							for (I = 0; I < SigLen; I++)
-								Sig[I] = (Sig[I] * NormFactor) / NormBase;
+
+						if (NormBase <= (DLReal) 0.0)
+							return False;
+
+						for (I = 0; I < SigLen; I++)
+							Sig[I] = (Sig[I] * NormFactor) / NormBase;
 					}
 				break;
 
@@ -147,6 +152,9 @@ void SigNormalize(DLReal * Sig,const int SigLen,const DLReal NormFactor,
 							if (((DLReal) fabs(Sig[I])) > NormBase)
 								NormBase = (DLReal) fabs(Sig[I]);
 
+						if (NormBase <= (DLReal) 0.0)
+							return False;
+
 						for (I = 0; I < SigLen; I++)
 							Sig[I] = (Sig[I] * NormFactor) / NormBase;
 					}
@@ -158,11 +166,46 @@ void SigNormalize(DLReal * Sig,const int SigLen,const DLReal NormFactor,
 						for (I = 0; I < SigLen; I++)
 							NormBase += (DLReal) fabs(Sig[I]);
 
+						if (NormBase <= (DLReal) 0.0)
+							return False;
+
 						for (I = 0; I < SigLen; I++)
 							Sig[I] = (Sig[I] * NormFactor) / NormBase;
 					}
 				break;
+
+				case NormFFTPeak:
+					{
+						if ((PFA = new DLComplex[SigLen]) == NULL)
+							return False;
+						for (I = 0; I < SigLen; I++)
+							PFA[I] = Sig[I];
+						if (Fft(PFA,SigLen) == False)
+							{
+								delete PFA;
+								return False;
+							}
+						NormBase = (DLReal) 0.0;
+						for (I = 0; I < SigLen / 2; I++)
+							{
+								CAV = std::abs<DLReal>(PFA[I]);
+								if (CAV > NormBase)
+									NormBase = CAV;
+							}
+						if (NormBase <= (DLReal) 0.0)
+							{
+								delete PFA;
+								return False;
+							}
+						for (I = 0; I < SigLen; I++)
+							Sig[I] = (Sig[I] * NormFactor) / NormBase;
+						delete PFA;
+					}
+				break;
 			}
+
+		/* Operazione completata */
+		return True;
 	}
 
 /* Limitazione valli a fase lineare con calcolo del valore RMS sull banda indicata */
